package de.aes.camdroid;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.List;

import android.content.Context;
import android.hardware.Camera.Parameters;
import android.hardware.Camera.Size;

/**
 * Clase que ajusta los parametros necesarios para correr el programa en main
 * @author Catrileo,Quiroz,Rodriguez
 *
 */
public class Settings
{
	public final int webWorker = 5;
	public final int webTimeout = 5000;
	private int webPort;
	private Context conText;
	private int PicFrmId;
	private List<Integer> PicFrmList;
	private int PicResId;
	private List<Size> PicResList;
	private int PictureQ;
/**
 * Constructor	
 * @param context
 * @param camParams
 */
	public Settings(Context context, Parameters camParams)
	{
		setConfig(context, camParams);
	}

	private boolean int2storage(String name, int value)
	{
		try
		{
			File file = new File(conText.getFilesDir(), name);
			FileOutputStream fos = new FileOutputStream(file);
			byte[] data = new byte[4];
			 
			// int -> byte[]
			for (int i = 0; i < 4; ++i) {
			    int shift = i << 3; // i * 8
			    data[3-i] = (byte)((value & (0xff << shift)) >>> shift);
			}
			fos.write(data);
		}
		catch (Exception e)
		{
			return false;
		}
		
		return true;
	}
	
	private int storage2int (String name)
	{
		int value=0;
		try
		{
			File file = new File(conText.getFilesDir(), name);
			if (!file.exists()) return -1;
			
			FileInputStream fis = new FileInputStream(file);
			byte[] data = new byte[4];
			fis.read(data);
			fis.close();
             // byte[] -> int
			for (int i = 0; i < 4; ++i)
			{
				value |= (data[3-i] & 0xff) << (i << 3);
            }
		}
		catch (Exception e)
		{
			return -1;
		}
		
		return value;
	}
/**
 * Asigna valores de los parametros	
 * @param context
 * @param camParams
 */
	private void setConfig(Context context, Parameters camParams)
	{
		this.conText = context;
		
		this.PicFrmList = camParams.getSupportedPreviewFrameRates();
		
		this.PicFrmId = storage2int("PicFrmId");
		if (this.PicFrmId == -1) this.PicFrmId = (this.PicFrmList.size()-1) / 2;
		
		this.PicResList = camParams.getSupportedPreviewSizes();
		
		this.PicResId = storage2int("PicResId");
		if (this.PicResId == -1) this.PicResId = (this.PicResList.size()-1) / 2;
		
		this.PictureQ = storage2int("PictureQ");
		if (this.PictureQ == -1) this.PictureQ = 50;
		
		this.webPort = storage2int("webPort");
		if (this.webPort == -1) this.webPort = 8080;
		
		saveConfig();
	}
/**
 * Guarda los valores actuales	
 */
	public void saveConfig()
	{
		int2storage("PicFrmId", this.PicFrmId);
		int2storage("PicResId", this.PicResId);
		int2storage("PictureQ", this.PictureQ);
		int2storage("webPort", this.webPort);
	}
/**
 * Asigna el valor de framerate	
 * @param step
 */
	public void PicFrmId(int step) {
		step = (this.PicFrmId + step)%this.PicFrmList.size();
		if (step<0) step += this.PicFrmList.size();
		this.PicFrmId = step;
	}
/**
 * Asigna el valor de resolucion de imagen	
 * @param step
 */
	public void PicResId(int step) {
		step = (this.PicResId + step)%this.PicResList.size();
		if (step<0) step += this.PicResList.size();
		this.PicResId = step;
	}
/**
 * Retorna el ancho de la imagen
 * @return int
 */
	public int PictureW()
	{
		return this.PicResList.get(PicResId).width;
	}
/**
 * Retorna el alto de la imagen	
 * @return int
 */
	public int PictureH()
	{
		return this.PicResList.get(PicResId).height;
	}
	
	public int FrameRate()
	{
		return this.PicFrmList.get(PicFrmId);
	}
/**
 * Disminuye la resolucion de imagen	
 */
	public void minPicRes()
	{
		this.PicResId = this.PicResList.size()-1;
	}
/**
 * Aumenta la resolucion de imagen	
 */
	public void maxPicRes()
	{
		this.PicResId = 0;
	}
/**
 * Disminuye el framerate	
 */
	public void minFrmRate()
	{
		this.PicFrmId = this.PicFrmList.size()-1;
	}
/**
 * Aumenta el framerate	
 */
	public void maxFrmRate()
	{
		this.PicFrmId = 0;
	}

	public int PictureQ()
	{
		return this.PictureQ;
	}
/**
 * Determina la calidad de la imagen	
 * @param step
 */
	public void PictureQ(int step)
	{
		step += this.PictureQ;
		if (step>100) 	step = 100;
		if (step<0)		step = 0;
		this.PictureQ = step;
	}
/**
 * Asigna el puerto ingresado	
 * @param port
 */
	public void webPort(int port)
	{
		webPort = port;
	}
	
	public int webPort()
	{
		return this.webPort;
	}
}
